@@ -1,5 +1,5 @@
 package Dependency::Resolver;
-$Dependency::Resolver::VERSION = '0.03';
+$Dependency::Resolver::VERSION = '0.04';
 use utf8;
 use Moose;
 
@@ -12,14 +12,14 @@ sub dep_resolv {
     #print $node->name . "\n";
     push( @$seen, $node);
 
-    for my $edge ( @{$node->edges} ) {
-        # if edge is not in resolved
-        if ( ! grep { $_ eq $edge} @$resolved ) {
+    for my $dep ( @{$node->deps} ) {
+        # if dep is not in resolved
+        if ( ! grep { $_ eq $dep} @$resolved ) {
 
-            die sprintf "Circular reference detected: %s -> %s", $node->name, $edge->name
-                if ( grep { $_ eq $edge} @$seen);
+            die sprintf "Circular reference detected: %s -> %s", $node->name, $dep->name
+                if ( grep { $_ eq $dep} @$seen);
 
-            $self->dep_resolv( $edge, $resolved, $seen );
+            $self->dep_resolv( $dep, $resolved, $seen );
         }
     }
     push( @$resolved, $node);
@@ -35,7 +35,7 @@ Dependency::Resolver - Dependency resolving algorithm
 
 =head1 VERSION
 
-version 0.03
+version 0.04
 
 based on http://www.electricmonk.nl/log/2008/08/07/dependency-resolving-algorithm/
 
@@ -47,12 +47,12 @@ my $c = Dependency::Resolver::Node->new( name => 'c' );
 my $d = Dependency::Resolver::Node->new( name => 'd' );
 my $e = Dependency::Resolver::Node->new( name => 'e' );
 
-$a->addEdge($b);    # a depends on b
-$a->addEdge($d);    # a depends on d
-$b->addEdge($c);    # b depends on c
-$b->addEdge($e);    # b depends on e
-$c->addEdge($d);    # c depends on d
-$c->addEdge($e);    # c depends on e
+$a->addDep($b);    # a depends on b
+$a->addDep($d);    # a depends on d
+$b->addDep($c);    # b depends on c
+$b->addDep($e);    # b depends on e
+$c->addDep($d);    # c depends on d
+$c->addDep($e);    # c depends on e
 
 my $resolver = Dependency::Resolver->new;
 
