@@ -1,5 +1,5 @@
 package Dependency::Resolver::Node;
-$Dependency::Resolver::Node::VERSION = '0.03';
+$Dependency::Resolver::Node::VERSION = '0.04';
 use utf8;
 use Moose;
 
@@ -10,25 +10,29 @@ has name => (
 );
 
 
-has edges => (
+has deps => (
                is       => "rw",
                isa      => "ArrayRef",
                default  => sub { [] },
            );
 
-sub addEdge {
+sub addDep {
     my ($self, $node) = @_;
 
-    push( @{$self->edges}, $node );
+    push( @{$self->deps}, $node );
 }
 
 =head1 NAME
 
 Dependency::Resolver::Node - Dependency resolver node
 
+
 =head1 VERSION
 
-version 0.03
+version 0.04
+
+This module is at EXPERIMENTAL stage, so use with caution.
+
 
 =head1 SYNOPSIS
 
@@ -38,22 +42,22 @@ my $c = Dependency::Resolver::Node->new( name => 'c' );
 my $d = Dependency::Resolver::Node->new( name => 'd' );
 my $e = Dependency::Resolver::Node->new( name => 'e' );
 
-$a->addEdge($b);    # a depends on b
-$a->addEdge($d);    # a depends on d
-$b->addEdge($c);    # b depends on c
-$b->addEdge($e);    # b depends on e
-$c->addEdge($d);    # c depends on d
-$c->addEdge($e);    # c depends on e
+$a->addDep($b);    # a depends on b
+$a->addDep($d);    # a depends on d
+$b->addDep($c);    # b depends on c
+$b->addDep($e);    # b depends on e
+$c->addDep($d);    # c depends on d
+$c->addDep($e);    # c depends on e
 
 
 =head1 SUBROUTINES/METHODS
 
 =head2 new( name => '...')
 
-=head2 addEdge($edge)
+=head2 addDep($dep)
 
 # node A depnds on nodeB
-$nodeA->addEdge($nodeB);
+$nodeA->addDep($nodeB);
 
 =head1 AUTHOR
 
